# Quicklogic Boards

The {py:mod}`torii.platform.vendor.quicklogic` module provides a base platform to support Quicklogic toolchains with the [Symbiflow] toolchain.

```{eval-rst}
.. automodule:: torii_boards.quicklogic.quickfeather
  :members:

```

[Symbiflow]: https://github.com/QuickLogic-Corp/quicklogic-fpga-toolchain
